FilterConditionType enum
The type of dynamic filter conditions.
Values
- equalTo → const FilterConditionType
-
Filter checking for equality.
- greaterThan → const FilterConditionType
-
Filter matching values greater than the bound.
- lessThan → const FilterConditionType
-
Filter matching values smaller than the bound.
- between → const FilterConditionType
-
Filter matching values between the bounds.
- startsWith → const FilterConditionType
-
Filter matching String values starting with the prefix.
- endsWith → const FilterConditionType
-
Filter matching String values ending with the suffix.
- contains → const FilterConditionType
-
Filter matching String values containing the String.
- matches → const FilterConditionType
-
Filter matching String values matching the wildcard.
- isNull → const FilterConditionType
-
Filter matching values that are
null. - isNotNull → const FilterConditionType
-
Filter matching values that are not
null. - elementIsNull → const FilterConditionType
-
Filter matching lists that contain
null. - elementIsNotNull → const FilterConditionType
-
Filter matching lists that contain an element that is not
null. - listLength → const FilterConditionType
-
Filter matching the length of a list.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FilterConditionType> - A constant List of the values in this enum, in order of their declaration.